@@ -5,17 +5,15 @@ from etl_bq_tools.functions.bigquery import bq_delete_dataset
 from etl_bq_tools.functions.bigquery import bq_delete_table
 from etl_bq_tools.functions.bigquery import bq_list_dataset
 from etl_bq_tools.functions.bigquery import bq_list_tables
+from etl_bq_tools.functions.bigquery import bq_query_to_df
 from etl_bq_tools.functions.bq import bq_execute_sql
 from etl_bq_tools.functions.bq import bq_set_project
+from etl_bq_tools.functions.cloud_storage import gs_bucket_list_patterns
+from etl_bq_tools.functions.cloud_storage import gs_bucket_list_to_df
 from etl_bq_tools.functions.dataframe import upload_df_to_bq
-from etl_bq_tools.functions.dataframe import upload_uri_to_bq
-from etl_bq_tools.functions.cloud_storage import gs_bucket_list
-from etl_bq_tools.functions.utils import get_reduce_memory
-
 from etl_bq_tools.utils.logger import get_logger
-from etl_bq_tools.utils.memory import reduce_memory
-
-from etl_bq_tools.utils.time_execution import time_function_execution
+from etl_bq_tools.utils.memory import get_reduce_memory
+from etl_bq_tools.utils.time_execution import get_time_function_execution
 
 __all__ = ["bq_copy_table",
            "bq_create_dataset",
@@ -26,10 +24,10 @@ __all__ = ["bq_copy_table",
            "bq_list_tables",
            "bq_execute_sql",
            "bq_set_project",
+           "bq_query_to_df",
            "upload_df_to_bq",
-           "upload_uri_to_bq",
            "get_reduce_memory",
            "get_logger",
-           "reduce_memory",
-           "gs_bucket_list",
-           "time_function_execution"]
+           "gs_bucket_list_patterns",
+           "gs_bucket_list_to_df",
+           "get_time_function_execution"]
