@@ -20,14 +20,14 @@ def get_stage(title, content):
     print(t)
 
 
-def time_function_execution(function_to_execute):
+def get_time_function_execution(function_to_execute):
     def compute_execution_time(*args, **kwargs):
         start_time = time.time()
-        _ = function_to_execute(*args, **kwargs)
+        result = function_to_execute(*args, **kwargs)
         end_time = time.time()
         tmin, tsec = divmod(datetime.timedelta(seconds=end_time - start_time).total_seconds(), 60)
         title = f"Time Execution: "
         content = f"{tmin:.0f} minutes and {round(tsec, 2)} seconds."
         get_stage(title, content)
-
+        return result
     return compute_execution_time
